@@ -10,6 +10,7 @@ from djangoldp_like.models import Like
 from django.utils import timezone
 from django.template import loader
 from djangoldp_i18n.views import I18nLDPViewSet
+from django.utils.translation import ugettext_lazy as _
 
 class LearningOutcome (Model) :
     name = models.CharField(max_length=256, verbose_name="Learning outcome", null=True, blank=True)
@@ -259,12 +260,12 @@ class Resource (Model):
         owner_perms = ['inherit', 'change', 'control', 'delete']
         nested_fields=["submitter",\
                        "format", "conversations", "steps", "languages", "fields",\
-                       "type", "related", "likes", "review", "country", "skills"]
+                       "type", "related", "likes", "review", "country", "skills", "brokenlinks"]
         serializer_fields=["@id", "name", "description", "resource_author", "uri", "publication_year", "submitter",\
                            "format", "target", "skills",\
                            "conversations", "steps", "languages", "fields", "country",\
                            "type", "submitter", "related", "likes", "review", "sharing",\
-                           "preview_image", "iframe_link"]
+                           "preview_image", "iframe_link", "brokenlinks"]
         container_path = 'resources/'
         rdf_type = 'coopstarter:resource'
         anonymous_perms = ['view']
@@ -311,9 +312,9 @@ class Request (Model):
         return str(self.name)
 
 class BrokenLink(Model):
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, related_name="brokenlink_submitter",
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, related_name="brokenlinks",
                                   null=True, blank=True)
-    resource = models.ForeignKey(Resource, null=True, on_delete=models.SET_NULL, related_name="brokenlink_resource")
+    resource = models.ForeignKey(Resource, null=True, on_delete=models.SET_NULL, related_name="brokenlinks")
     
     class Meta:
         auto_author = 'submitter'
@@ -360,7 +361,7 @@ def create_review(sender, instance, created, **kwargs):
                 )
 
                 send_mail(
-                    'The resource you reviewed has been modified',
+                    _('The resource you reviewed has been modified'),
                     message_text,
                     '"Knowledge Base" <kb@starter.coop>',
                     [review.reviewer.email],
@@ -376,7 +377,7 @@ def update_review(sender, instance, created, **kwargs):
         if getattr(settings, 'UPDATE_REVIEW', True) and instance.resource is not None:
             resource = instance.resource
             if instance.status == 'validated':
-                subject = 'The resource you submitted has been validated !'
+                subject = _('The resource you submitted has been validated !')
                 message = loader.render_to_string(
                     'emails/txt/resource_validation_notification.txt', 
                     {
@@ -392,7 +393,7 @@ def update_review(sender, instance, created, **kwargs):
                     }
                 )
             elif instance.status == 'to_improve':
-                subject = 'The resource you submitted requires some improvements'
+                subject = _('The resource you submitted requires some improvements')
                 message = loader.render_to_string(
                     'emails/txt/resource_improvement_notification.txt', 
                     {
@@ -408,7 +409,7 @@ def update_review(sender, instance, created, **kwargs):
                     }
                 )
             elif instance.status == 'inappropriate':
-                subject = 'The resource you submitted is considered inappropriate'
+                subject = _('The resource you submitted is considered inappropriate')
                 message = loader.render_to_string(
                     'emails/txt/resource_refusal_notification.txt', 
                     {
@@ -435,7 +436,7 @@ def update_review(sender, instance, created, **kwargs):
 
 
 @receiver(post_save, sender=BrokenLink)
-def sendMailToResourceSubmitter(sender, instance, created, **kwargs):
+def send_mail_to_resource_submitter(sender, instance, created, **kwargs):
     if created:
         message_text = loader.render_to_string(
             'emails/txt/report_broken_link.txt',
@@ -452,13 +453,38 @@ def sendMailToResourceSubmitter(sender, instance, created, **kwargs):
         )
 
         send_mail(
-            'The resource you submitted has a brokenlink',
+            _('The resource you submitted has a brokenlink'),
             message_text,
             '"Knowledge Base" <kb@starter.coop>',
             [instance.resource.submitter.email],
             html_message=message_html
         )
 
+@receiver(post_save, sender=Request)
+def send_mail_to_request_submitter(sender, instance, created, **kwargs):
+    if not created and instance.status == 'validated':
+        message_text = loader.render_to_string(
+            'emails/txt/request_managed.txt',
+            {
+                'request': instance,
+            }
+        )
+
+        message_html = loader.render_to_string(
+            'emails/html/request_managed.html',
+            {
+                'request': instance,
+            }
+        )
+
+        send_mail(
+            _('The request for a resource you submitted has been managed'),
+            message_text,
+            '"Knowledge Base" <kb@starter.coop>',
+            [instance.submitter.email],
+            html_message=message_html
+        )
+
 @receiver(post_save, sender=Contributor)
 def create_contributor_profile(sender, instance, created, **kwargs):
     if kwargs.get('raw', False):
@@ -483,7 +509,7 @@ def create_contributor_profile(sender, instance, created, **kwargs):
                 }
             )
             send_mail(
-                'New user account registration',
+                _('New contributor profile completed'),
                 message_text,
                 '"Knowledge Base" <kb@starter.coop>',
                 [user.email],
@@ -514,7 +540,7 @@ def create_user(sender, instance, created, **kwargs):
                 }
             )
             send_mail(
-                'New user account registration',
+                _('New user account registration'),
                 message_text,
                 '"Knowledge Base" <kb@starter.coop>',
                 [user.email],
